@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: mod_uploader.h.in 426 2005-07-03 19:24:03Z svn $
+ * $Id: Misc.h 1003 2006-03-14 13:52:47Z svn $
  *****************************************************************************/
 
 /**
@@ -105,6 +105,11 @@
         exit(EXIT_SUCCESS);                                             \
     }
 
+// strncpy_s Υå
+#ifdef _MSC_VER
+#define strncpy(dst, src, count) strncpy_s(dst, count, src, _TRUNCATE)
+#endif
+
 // Local Variables:
 // mode: c++
 // buffer-file-coding-system: euc-japan-dos
