@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: MmapFileWriter.h 733 2005-09-24 20:00:54Z svn $
+ * $Id: MmapFileWriter.h 1003 2006-03-14 13:52:47Z svn $
  *****************************************************************************/
 
 #ifndef MMAP_FILE_WRITER_H
@@ -79,6 +79,7 @@ public:
      * եĤޤ
      */
     ~MmapFileWriter();
+
 private:
     /**
      * mmap ˤƤΥ֥å
@@ -105,11 +106,11 @@ private:
     /** mmap ξ */
     apr_mmap_t *file_map_;
     /** ߥޥåפƤ֥åΥǥå */
-    apr_size_t size_factor_;
+    apr_uint64_t offset_factor_;
     /** mmap ˤƤΥ֥å */
     const apr_size_t block_size_;
     /** ˽񤭹֥åΰ */
-    apr_size_t offset_;
+    apr_size_t block_offset_;
     /** ˥ե뤬 close 줿ɤ */
     bool is_closed_;
 };
