@@ -24,18 +24,15 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemList.h 746 2005-09-25 09:27:50Z svn $
+ * $Id: UploadItemList.h 1003 2006-03-14 13:52:47Z svn $
  *****************************************************************************/
 
-#ifndef UPLOADITEMLIST_H
-#define UPLOADITEMLIST_H
+#ifndef UPLOAD_ITEM_LIST_H
+#define UPLOAD_ITEM_LIST_H
 
 #include "UploadItem.h"
 #include "UploadItemReader.h"
 #include "TemplateVariable.h"
-#ifdef MAKE_THUMBNAIL
-#include "ThumbnailWriter.h"
-#endif
 
 #include "apr_pools.h"
 
@@ -49,6 +46,17 @@
 
 using namespace std;
 
+#ifdef MAKE_THUMBNAIL
+#ifdef WIN32
+class WindowsThumbnailWriter;
+typedef WindowsThumbnailWriter ThumbnailWriterImpl;
+#else
+class UnixThumbnailWriter;
+typedef UnixThumbnailWriter ThumbnailWriterImpl;
+#endif
+#endif
+
+
 /**
  * @brief åץɥƥδԤ饹
  */
@@ -91,6 +99,8 @@ public:
 #ifdef DEBUG
     static void dump_list(UploadItemList *item_list);
 #endif
+    ~UploadItemList();
+
 private:
     static const char PATH_CACHE_FILENAME[];
     static const char HEADER_CACHE_FILENAME[];
@@ -162,7 +172,7 @@ private:
 
     UploadItemReader reader_;
 #ifdef MAKE_THUMBNAIL
-    ThumbnailWriter twriter_;
+    ThumbnailWriterImpl *twriter_;
 #endif
     apr_uint64_t total_size_;
     item_list ilist_;
