@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: MmapFileWriter.cpp 724 2005-09-24 05:02:17Z svn $
+ * $Id: MmapFileWriter.cpp 1003 2006-03-14 13:52:47Z svn $
  *****************************************************************************/
 
 #include "MmapFileWriter.h"
@@ -56,14 +56,14 @@ const apr_size_t MmapFileWriter::PAGE_SIZE      = MMAP_PAGE_SIZE;
 MmapFileWriter::MmapFileWriter(apr_pool_t *pool, apr_file_t *fd, apr_size_t offset)
     : FileWriter(pool, fd),
       file_map_(NULL),
-      size_factor_(0),
+      offset_factor_(0),
       // ڡܿñ̤ǳƤ
       block_size_(((BLOCK_SIZE-1)/PAGE_SIZE + 1) * PAGE_SIZE),
-      offset_(0),
+      block_offset_(0),
       is_closed_(false)
 {
     expand();
-    offset_ = offset;
+    block_offset_ = offset;
 }
 
 void MmapFileWriter::write(const void *buf, apr_size_t size)
@@ -76,11 +76,11 @@ void MmapFileWriter::write(const void *buf, apr_size_t size)
     while (size > 0) {
         write_size = (size > block_size_) ? block_size_ : size;
 
-        if (write_size > (block_size_-offset_)) {
-            if (offset_ != block_size_) {
-                write_size = block_size_ - offset_;
+        if (write_size > (block_size_-block_offset_)) {
+            if (block_offset_ != block_size_) {
+                write_size = block_size_ - block_offset_;
 
-                memcpy(static_cast<char *>(file_map_->mm)+offset_, data, write_size);
+                memcpy(static_cast<char *>(file_map_->mm)+block_offset_, data, write_size);
                 data += write_size;
                 size -= write_size;
             }
@@ -89,10 +89,10 @@ void MmapFileWriter::write(const void *buf, apr_size_t size)
             continue;
         }
 
-        memcpy(static_cast<char *>(file_map_->mm)+offset_, data, write_size);
+        memcpy(static_cast<char *>(file_map_->mm)+block_offset_, data, write_size);
 
         data += write_size;
-        offset_ += write_size;
+        block_offset_ += write_size;
         size -= write_size;
     }
 }
@@ -108,7 +108,7 @@ void MmapFileWriter::close()
             throw "ե unmap ˼Ԥޤ";
         }
     }
-    if (apr_file_trunc(get_fd(), block_size_*(size_factor_-1)+offset_) != APR_SUCCESS) {
+    if (apr_file_trunc(get_fd(), block_size_*(offset_factor_-1)+block_offset_) != APR_SUCCESS) {
         throw "ե truncate ˼Ԥޤ";
     }
     FileWriter::close();
@@ -140,8 +140,8 @@ void MmapFileWriter::expand()
         }
     }
 
-    size_factor_++;
-    offset = pseudo_size = block_size_*size_factor_;
+    offset_factor_++;
+    offset = pseudo_size = block_size_*offset_factor_;
 
     if ((apr_file_seek(get_fd(), APR_SET, &offset) != APR_SUCCESS) ||
         (offset != pseudo_size)) {
@@ -157,7 +157,7 @@ void MmapFileWriter::expand()
         throw "ե map ˼Ԥޤ";
     }
 
-    offset_ = 0;
+    block_offset_ = 0;
 }
 
 
