@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: RFC1867Parser.cpp 913 2005-10-29 18:33:54Z svn $
+ * $Id: RFC1867Parser.cpp 1063 2006-05-13 03:10:51Z svn $
  *****************************************************************************/
 
 #include "RFC1867Parser.h"
@@ -107,10 +107,10 @@ RFC1867Parser<FileWriterClass, PostReaderClass>::MKTEMP_RETRY_NUMBER = 10;
  *****************************************************************************/
 template<class FileWriterClass, class PostReaderClass>
 RFC1867Parser<FileWriterClass, PostReaderClass>::RFC1867Parser(const char *file_dir,
-                                              apr_size_t max_text_size,
-                                              apr_size_t max_file_size,
-                                              apr_size_t max_item_num,
-                                              apr_size_t file_offset)
+                                                               apr_size_t max_text_size,
+                                                               apr_uint64_t max_file_size,
+                                                               apr_size_t max_item_num,
+                                                               apr_size_t file_offset)
     : file_dir_(file_dir),
       max_text_size_(max_text_size),
       max_file_size_(max_file_size),
@@ -125,7 +125,7 @@ RFC1867Data::query_map
 *RFC1867Parser<FileWriterClass, PostReaderClass>::parse(apr_pool_t *pool,
                                                         PostReaderClass& reader,
                                                         const char *content_type,
-                                                        apr_size_t content_size)
+                                                        apr_uint64_t content_size)
 {
     const char *boundary;
     query_map *qmap = NULL;
@@ -138,7 +138,7 @@ RFC1867Data::query_map
     DirectoryCleaner::cleanOldFiles(pool, file_dir_, READ_TIMEOUT_SEC);
 
     // "" å
-    if (content_size > (max_text_size_+max_file_size_)/2*max_item_num_) {
+    if (content_size > (max_text_size_+max_file_size_)*max_item_num_) {
         throw "åץɥǡ礭ޤ";
     }
 
@@ -146,7 +146,7 @@ RFC1867Data::query_map
     boundary = get_boundary(pool, content_type);
     try {
         handle h(pool, reader, boundary, qmap);
-        if (store_buffer(h) == 0) {
+        if (fill_buffer(h) == 0) {
             DUMP_INPUT(h.buffer.data());
             throw "Ϥޤ";
         }
@@ -229,7 +229,7 @@ bool RFC1867Parser<FileWriterClass, PostReaderClass>::get_content(handle& h,
     const char *start;
     const char *end;
 
-    if ((store_buffer(h) == 0) && (h.buffer.size() == 0)) {
+    if ((fill_buffer(h) == 0) && (h.buffer.size() == 0)) {
         DUMP_INPUT(h.buffer.data());
         throw "ϤǽλƤޤ(1)";
     }
@@ -298,7 +298,7 @@ const char *RFC1867Parser<FileWriterClass, PostReaderClass>::get_text_content(ha
     const char *end;
     apr_size_t read_size = READ_BLOCK_SIZE;
 
-    store_buffer(h);
+    fill_buffer(h);
     start = h.buffer.data();
     end = static_cast<const char *>(memmem(start, h.buffer.size(), h.boundary, h.boundary_len));
 
@@ -392,7 +392,7 @@ const char *RFC1867Parser<FileWriterClass, PostReaderClass>::get_file_content(ha
                            file_offset_);
     MessageDigest5 digest;
 
-    store_buffer(h);
+    fill_buffer(h);
     start = h.buffer.data();
     end = static_cast<const char *>(memmem(start, h.buffer.size(), h.boundary, h.boundary_len));
 
@@ -410,7 +410,7 @@ const char *RFC1867Parser<FileWriterClass, PostReaderClass>::get_file_content(ha
             *file_size += write_size;
             h.buffer.erase(write_size);
 
-            read_size = store_buffer(h);
+            read_size = fill_buffer(h);
 
             start = h.buffer.data();
 
@@ -441,7 +441,7 @@ const char *RFC1867Parser<FileWriterClass, PostReaderClass>::get_file_content(ha
 }
 
 template<class FileWriterClass, class PostReaderClass>
-apr_size_t RFC1867Parser<FileWriterClass, PostReaderClass>::store_buffer(handle& h)
+apr_size_t RFC1867Parser<FileWriterClass, PostReaderClass>::fill_buffer(handle& h)
 {
     apr_size_t size;
     apr_size_t read_size = 0;
