@@ -27,8 +27,8 @@
  * $Id: UploadItemList.cpp 148 2005-03-19 03:57:09Z svn $
  *****************************************************************************/
 
-// RSS ¾ʬ٤ˤ˥ǽΤǡƥץ졼
-// ȵǽȤ鷺ϡɥǥ󥰤Ƥޤ
+// RSS ƤѹɬפޤʤΤǡƥץ졼ȵǽȤ鷺ϡ
+// ɥǥ󥰤Ƥޤ
 
 #include "RssView.h"
 #include "TemplateVariableCreator.h"
@@ -140,7 +140,7 @@ void RssView<ResponseWriterClass>::print(handle *h, item_info *item)
     print(h, time_str(pool_, item->header->time));
     print(h, "</dc:date>");
 
-    print(h, "</item>");
+    print(h, "</item>\n");
 }
 
 template<class ResponseWriterClass>
