@@ -24,12 +24,24 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemList.cpp 895 2005-10-23 18:50:50Z svn $
+ * $Id: UploadItemList.cpp 1029 2006-04-17 12:09:02Z svn $
  *****************************************************************************/
 
+#ifdef WIN32
+#include <windows.h>
+#include <vfw.h>
+#endif
+
 #include "UploadItemList.h"
 #include "UploadVariableCreator.h"
 #include "Misc.h"
+#ifdef MAKE_THUMBNAIL
+#ifdef WIN32
+#include "WindowsThumbnailWriter.h"
+#else
+#include "UnixThumbnailWriter.h"
+#endif
+#endif
 
 #include "apr_strings.h"
 #include "apr_tables.h"
@@ -63,13 +75,12 @@ UploadItemList::UploadItemList(apr_pool_t *pool,
       total_number_limit_(total_number_limit),
       total_size_limit_(total_size_limit),
       reader_(pool, file_dir),
-#ifdef MAKE_THUMBNAIL
-      twriter_(pool, file_dir, thumb_dir),
-#endif
       total_size_(0),
       revision_(0)
 {
-
+#ifdef MAKE_THUMBNAIL
+    twriter_ = new ThumbnailWriterImpl(pool_, file_dir_, thumb_dir_);
+#endif
 }
 
 void UploadItemList::add(const char *file_path, bool is_new)
@@ -191,15 +202,34 @@ TemplateVariable::variable *UploadItemList::to_thumb_varray(apr_pool_t *pool,
                                                static_cast<int>(sizeof(TemplateVariable::variable *)));
 
     thumb_iterator i = tlist_.begin();
+    item_iterator item_i;
+    item_iterator item_i_prev = begin();
     TemplateVariable::variable **var;
+    UploadItem item(pool);
 
     for (apr_size_t j = 0; (j < start) && (i != tlist_.end()); j++) {
         i++;
     }
 
+    // ι¤ȥͥΤɤե뼫ȤΤ
+    // ʤΤǡʣΨʽˤʤäƤޤ:-<
+    // item_i_prev ϡͥȥեʤäкѡ
+
     for (apr_size_t j = 0; (j < size) && (i != tlist_.end()); j++, ++i) {
-        var = static_cast<TemplateVariable::variable **>(apr_array_push(array));
-        *var = UploadVariableCreator::create(pool, (*i).c_str());
+        for (item_i = item_i_prev; item_i != end(); ++item_i) {
+            if (strcmp((*i).c_str(), (*item_i)->file_path) != 0) {
+                continue;
+            }
+
+            item.set_data((*item_i)->file_path, (*item_i)->header);
+
+            var = static_cast<TemplateVariable::variable **>(apr_array_push(array));
+            *var = UploadVariableCreator::create(pool, &item);
+
+            item_i_prev = ++item_i;
+
+            break;
+        }
     }
 
     return UploadVariableCreator::create(pool, array);
@@ -262,6 +292,12 @@ void UploadItemList::dump_list(UploadItemList *item_list)
 }
 #endif
 
+UploadItemList::~UploadItemList(){
+#ifdef MAKE_THUMBNAIL
+    delete twriter_;
+#endif
+}
+
 
 /******************************************************************************
  * private ᥽å
@@ -423,7 +459,7 @@ void UploadItemList::add_new(item_info *info)
 
 #ifdef MAKE_THUMBNAIL
     try {
-        if (twriter_.write(info->file_path)) {
+        if (twriter_->write(info->file_path)) {
             tlist_.push_front(info->file_path);
         }
     } catch(const char *) {
@@ -552,7 +588,7 @@ void UploadItemList::read_path_cache(apr_pool_t *tmp_pool, char **paths,
     if (apr_file_open(&cache_file, path_cache_path_,
                       APR_READ|APR_BINARY,
                       APR_OS_DEFAULT, tmp_pool) != APR_SUCCESS) {
-        throw "åե򳫤ޤǤ";
+        throw "åե open ˼Ԥޤ";
     }
 
     if (apr_file_info_get(&info, APR_FINFO_SIZE, cache_file) != APR_SUCCESS) {
@@ -600,7 +636,7 @@ void UploadItemList::read_header_cache(apr_pool_t *tmp_pool,
     if (apr_file_open(&cache_file, header_cache_path_,
                       APR_READ|APR_BINARY,
                       APR_OS_DEFAULT, tmp_pool) != APR_SUCCESS) {
-        throw "åե򳫤ޤǤ";
+        throw "åե open ˼Ԥޤ";
     }
 
     if (apr_file_info_get(&info, APR_FINFO_SIZE, cache_file) != APR_SUCCESS) {
