@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: apache_handler.cpp 917 2005-11-21 11:19:09Z svn $
+ * $Id: apache_handler.cpp 1023 2006-04-16 16:53:14Z svn $
  *****************************************************************************/
 
 #include "apache_handler.h"
@@ -91,7 +91,7 @@ static apr_size_t get_page(request_rec *r)
     return get_page(r->args);
 }
 
-static apr_size_t get_upload_id(request_rec *r)
+static apr_uint32_t get_upload_id(request_rec *r)
 {
     return get_upload_id(r->args);
 }
@@ -312,7 +312,7 @@ static int rss(request_rec *r, uconfig *config, const char *arg)
 static int upload(request_rec *r, uconfig *config, const char *arg)
 {
     const char *address;
-    apr_size_t upload_id;
+    apr_uint32_t upload_id;
     pprogress *progress;
     apr_status_t status;
 
@@ -414,7 +414,7 @@ static int progress(request_rec *r, uconfig *config, const char *arg)
 
 static int progress_data(request_rec *r, uconfig *config, const char *arg)
 {
-    apr_size_t upload_id;
+    apr_uint32_t upload_id;
     pprogress *progress;
 
     upload_id = get_upload_id(r);
@@ -432,11 +432,40 @@ static int progress_data(request_rec *r, uconfig *config, const char *arg)
         return OK;
     }
 
-    ap_rprintf(r, "s %" APR_SIZE_T_FMT " %" APR_SIZE_T_FMT,
+    ap_rprintf(r, "s %" APR_UINT64_T_FMT " %" APR_UINT64_T_FMT,
                progress->total_size, progress->read_size);
     return OK;
 }
 
+static apr_status_t http_sendfile(apr_file_t *file, request_rec *r,
+                                  apr_off_t offset, apr_size_t length,
+                                  apr_size_t *send_bytes)
+{
+    conn_rec *c;
+    apr_bucket_brigade *bb;
+    apr_bucket *b;
+    apr_status_t status;
+
+    c = r->connection;
+
+    bb = apr_brigade_create(r->pool, c->bucket_alloc);
+
+    b = apr_bucket_file_create(file, offset, length, r->pool, c->bucket_alloc);
+    APR_BRIGADE_INSERT_TAIL(bb, b);
+
+    b = apr_bucket_eos_create(c->bucket_alloc);
+    APR_BRIGADE_INSERT_TAIL(bb, b);
+
+    status = ap_pass_brigade(r->output_filters, bb);
+    if (status != APR_SUCCESS) {
+        *send_bytes = 0;
+    } else {
+        *send_bytes = length;
+    }
+
+    return status;
+}
+
 static int download(request_rec *r, uconfig *config, const char *arg)
 {
     const char *name;
@@ -508,7 +537,11 @@ static int download(request_rec *r, uconfig *config, const char *arg)
                        apr_psprintf(r->pool,
                                     "%s; filename=\"%s\"", open_mode, file_name));
 
-        ap_send_fd(file, r, sizeof(UploadItem::header), header->file_size, &size);
+        http_sendfile(file, r, sizeof(UploadItem::header),
+                      static_cast<apr_size_t>(header->file_size), // MEMO: 4GB 
+                      &size);
+
+        apr_file_close(file);
 
         return OK;
     } catch(const char *message) {
