@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: cgi_handler.cpp 914 2005-11-17 15:07:03Z svn $
+ * $Id: cgi_handler.cpp 1034 2006-04-21 12:31:47Z svn $
  *****************************************************************************/
 
 #include "cgi_handler.h"
@@ -91,7 +91,7 @@ static apr_size_t get_page()
     return get_page(getenv("QUERY_STRING"));
 }
 
-static apr_size_t get_upload_id()
+static apr_uint32_t get_upload_id()
 {
     return get_upload_id(getenv("QUERY_STRING"));
 }
@@ -120,9 +120,9 @@ static void print_header_delimiter()
     cout << "\r\n";
 }
 
-static bool is_header_only()
+static bool is_header_only(apr_pool_t *pool)
 {
-    return strcmp(safe_getenv("REQUEST_METHOD"), "HEAD") == 0;
+    return strcmp(safe_getenv(pool, "REQUEST_METHOD"), "HEAD") == 0;
 }
 
 static void read_file(apr_pool_t *pool, uconfig *config,
@@ -408,7 +408,7 @@ static int view(apr_pool_t *pool, uconfig *config, const char *arg)
     print_content_type();
     print_header_delimiter();
 
-    if (is_header_only()) {
+    if (is_header_only(pool)) {
         return EXIT_SUCCESS;
     }
 
@@ -446,7 +446,7 @@ static int thumbnail(apr_pool_t *pool, uconfig *config, const char *arg)
     print_content_type();
     print_header_delimiter();
 
-    if (is_header_only()) {
+    if (is_header_only(pool)) {
         return EXIT_SUCCESS;
     }
 
@@ -484,7 +484,7 @@ static int rss(apr_pool_t *pool, uconfig *config, const char *arg)
     print_content_type(CGIRssView::content_type);
     print_header_delimiter();
 
-    if (is_header_only()) {
+    if (is_header_only(pool)) {
         return EXIT_SUCCESS;
     }
 
@@ -506,19 +506,19 @@ static int rss(apr_pool_t *pool, uconfig *config, const char *arg)
 static int upload(apr_pool_t *pool, uconfig *config, const char *arg)
 {
     const char *address;
-    apr_size_t upload_id;
+    apr_uint32_t upload_id;
     poster *poster_list;
     pprogress *progress_list;
     pprogress *progress;
 
-    if (strcmp(safe_getenv("REQUEST_METHOD"), "POST")) {
+    if (strcmp(safe_getenv(pool, "REQUEST_METHOD"), "POST")) {
         print_status(HTTP_BAD_REQUEST);
         print_header_delimiter();
 
         return EXIT_FAILURE;
     }
 
-    address = safe_getenv("REMOTE_ADDR");
+    address = safe_getenv(pool, "REMOTE_ADDR");
     poster_list = load_poster_list(pool, config);
     if (is_poster_list_contain(poster_list, address)) {
         return error(pool, config,
@@ -536,12 +536,12 @@ static int upload(apr_pool_t *pool, uconfig *config, const char *arg)
         const char *file_name;
         apr_size_t content_size;
 
-        content_size = static_cast<apr_size_t>(apr_atoi64(safe_getenv("CONTENT_LENGTH")));
+        content_size = static_cast<apr_size_t>(apr_atoi64(safe_getenv(pool, "CONTENT_LENGTH")));
         progress->total_size = content_size;
 
         CGIPostReader reader(progress);
         auto_ptr<RFC1867Data::query_map>
-            qmap(config->uparser->parse(pool, reader, safe_getenv("CONTENT_TYPE"),
+            qmap(config->uparser->parse(pool, reader, safe_getenv(pool, "CONTENT_TYPE"),
                                         content_size));
 
         try {
@@ -605,7 +605,7 @@ static int progress(apr_pool_t *pool, uconfig *config, const char *arg)
 
 static int progress_data(apr_pool_t *pool, uconfig *config, const char *arg)
 {
-    apr_size_t upload_id;
+    apr_uint32_t upload_id;
     pprogress *progress_list;
     pprogress *progress;
     char *progress_str;
@@ -630,7 +630,7 @@ static int progress_data(apr_pool_t *pool, uconfig *config, const char *arg)
         return EXIT_SUCCESS;
     }
 
-    progress_str = apr_psprintf(pool, "s %" APR_SIZE_T_FMT " %" APR_SIZE_T_FMT,
+    progress_str = apr_psprintf(pool, "s %" APR_UINT64_T_FMT " %" APR_UINT64_T_FMT,
                                 progress->total_size, progress->read_size);
     cout << progress_str;
 
@@ -699,7 +699,7 @@ static int download(apr_pool_t *pool, uconfig *config, const char *arg)
         print_last_modified(config->item_list->get_mtime());
         print_content_type(header->file_mime);
 
-        if (is_header_only()) {
+        if (is_header_only(pool)) {
             print_header_delimiter();
             return EXIT_SUCCESS;
         }
@@ -709,7 +709,7 @@ static int download(apr_pool_t *pool, uconfig *config, const char *arg)
                                                get_name_encoding());
 
         // ɽ⡼ or ɥ⡼
-        open_mode = (strlen(safe_getenv("QUERY_STRING")) == 0) ? "inline" : "attachment";
+        open_mode = (strlen(safe_getenv(pool, "QUERY_STRING")) == 0) ? "inline" : "attachment";
 
         // Content-Disposition
         content_dispos = apr_psprintf(pool, "%s; filename=\"%s\"", open_mode, file_name);
@@ -732,7 +732,7 @@ static int remove(apr_pool_t *pool, uconfig *config, const char *arg)
 {
     apr_table_t *ptable;
 
-    if (strcmp(safe_getenv("REQUEST_METHOD"), "POST")) {
+    if (strcmp(safe_getenv(pool, "REQUEST_METHOD"), "POST")) {
         print_status(HTTP_BAD_REQUEST);
         print_header_delimiter();
 
